@@ -5,9 +5,9 @@ import os
 def setup_poetry(config):
     """Entry point of module: setup poetry files and run poetry commands"""
     update_pyproject_dot_toml(config)
-    update_pyproject_dot_toml(config)
+    install_poetry()
     #lock_poetry_dependencies()
-    #install_dependencies()
+    install_dependencies()
 
 
 def lock_poetry_dependencies_on_docker():
@@ -20,6 +20,11 @@ def install_dependencies():
     os.system("poetry install")
 
 
+def install_poetry():
+    """Install poetry"""
+    os.system("pip install poetry")
+
+
 def update_pyproject_dot_toml(config):
     filename = "pyproject.toml"
     with open(filename) as f:
